<!DOCTYPE TS><TS>
<context>
    <name>AddClock</name>
    <message>
        <source>Add Log Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Clock Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>AddEvent</name>
    <message>
        <source>Add Log Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;New Event Name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ClockListView</name>
    <message>
        <source>Edit Event</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditClock</name>
    <message>
        <source>Edit Clock:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Count</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler
Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Colo&amp;r</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clock Modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The clock has been modified.
Do you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Missing Clock Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must specify a clock code!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Code Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The clock code is already in use!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clock already exists!  Overwrite?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--- End of clock ---</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You must provide a clock code!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Duplicate Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That code is already in use!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Remarks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Clone</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete
</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEvent</name>
    <message>
        <source>Editing Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Group:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macros Only</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CART</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>GROUP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TITLE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ARTIST</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>END</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TYPE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PRE-POSITION LOG</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cue to this event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>before scheduled start.  (First cart will have a STOP transition.)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TIMED START</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use hard start time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make Post Point</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Action If Previous Event Still Playing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Make next</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wait up to</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Play</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Segue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stop</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Transition if previous event ends before start time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ENFORCING LENGTH</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use AutoFill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Warn if fill is over or under</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>by at least</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use Timescaling</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>TRANSITION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>COUNT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>None</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>From Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select from:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Title Separation</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Must have code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import carts scheduled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>prior to the start of this event.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>after the end of this event.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>First cart has a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Imported carts have a</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>transition.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import inline traffic with the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>event.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>POST-IMPORT CARTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Services
List</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;olor</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event already exists!
Do you want to overwrite it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Audio</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Macro</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Timed(Start)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Timed(MakeNext)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Timed(Wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Post</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Fill</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Scale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Scheduler</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>, Inline Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>REMARKS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Len:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PRE-IMPORT CARTS</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>IMPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>and code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditEventLine</name>
    <message>
        <source>Edit Event Assignment</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Start Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>End Time:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The event end time cannot be earlier than the start time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Such Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>There is no such event.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This event overlaps with an
already existing event.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditGrid</name>
    <message>
        <source>Edit Grid:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Hour</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Change
&amp;All</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear Clocks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to update ALL clocks in the grid?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This operation cannot be undone!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditNote</name>
    <message>
        <source>Edit Log Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditPerms</name>
    <message>
        <source>Service Associations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enabled Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditSchedRules</name>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Import</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>CODE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MAX. IN A ROW</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>MIN. WAIT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DO NOT SCHEDULE AFTER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OR AFTER</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>DESCRIPTION</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Codes:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Rules Modified</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The rules have been modified.
Do you want to save?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheduler Rules</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Artist Separation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Rules from Clock</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>EditTrack</name>
    <message>
        <source>Edit Voice Track Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>GenerateLog</name>
    <message>
        <source>Generating Log...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Service:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Create New Log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge &amp;Music</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merge &amp;Traffic</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Import Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Merged</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The log for</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already exists.  Recreating it
will remove any merged Music or Traffic events.

Recreate?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This will also delete the</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>voice tracks associated with this log.
Continue?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tracks Exist</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No Errors</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No exceptions found.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged music and/or traffic data.
Remerging it will remove this data.  Remerge?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Music Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>already contains merged traffic data.  Remerging it
will remove this data.  Remerge?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Traffic Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Generate Log - User: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to generate log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear traffic links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to clear music links</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to link music log</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unable to link traffic log</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ImportListView</name>
    <message>
        <source>Insert Log Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Log Note</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Insert Voice Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Voice Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set PLAY Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set SEGUE Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set STOP Transition</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Marker</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Log Note]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Track</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[Voice Track]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>PLAY</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SEGUE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>STOP</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListClocks</name>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Code</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NONE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clock Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An clock with that name already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following grid(s):</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clock In Use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Clocks - User: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListEvents</name>
    <message>
        <source>Filter:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Properties</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Color</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Ok</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>ALL</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>NONE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event Exists</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>An event with that name already exists!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to
delete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Event</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>is in use in the following clocks:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do you still want to delete it?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Event In Use</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Log Events - User: </source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListGrids</name>
    <message>
        <source>Log Grids</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Description</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ListSvcs</name>
    <message>
        <source>Rivendell Services</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>SERVICE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>OLDEST REPORT</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>[none]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWidget</name>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogManager</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select an operation:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit &amp;Events</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit C&amp;locks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit G&amp;rids</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate Logs</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Manage &amp;Reports</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogManager - User: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>RDLogEdit -- Database Skew</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This version of RDLogManager is incompatible with the version installed on the server.
See your system administrator for an update!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PickReportDates</name>
    <message>
        <source>Select Report Dates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Report:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Start Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Select</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;End Date:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Generate
Report</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Invalid Date Range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The end date cannot be earlier than the start date!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This report type cannot span multiple dates!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This report type cannot span multiple months!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report Complete</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Report generated in</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>RenameItem</name>
    <message>
        <source>Rename</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name Conflict</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>That name already exists!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SvcRec</name>
    <message>
        <source>Mo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tu</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>We</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Th</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fr</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sa</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Su</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SvcRecDialog</name>
    <message>
        <source>Report Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Purge
Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete Report Data</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Are you sure you want to delete report data for</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>editSchedCodeRules</name>
    <message>
        <source>&amp;OK</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Code:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Max. in a row:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Min. wait:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not schedule after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Or after:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit Rules for Code</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
